==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/SummaryRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
export let SummaryRowDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryRowDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryRowDescriptionMetadata.a == null) {
                SummaryRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryRowDescriptionMetadata.c(SummaryRowDescriptionMetadata.a);
            }
            if (a.j(SummaryRowDescriptionMetadata.a)) {
                return;
            }
            a.y(SummaryRowDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SelectedBackground", "Brush");
            a.item("ActualSelectedBackground", "Brush");
            a.item("SummaryLabelTextColor", "Brush");
            a.item("ActualSummaryLabelTextColor", "Brush");
            a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:summaryNameTextStyle/FontFamilyTransform)String");
            a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:summaryNameTextStyle/FontSizeTransform)Number:double");
            a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:summaryNameTextStyle/FontStyleTransform)String");
            a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:summaryNameTextStyle/FontWeightTransform)String");
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
        }
        static d(a) {
            SummaryRowDescriptionMetadata.b(a);
            a.z("SummaryRow", SummaryRowDescriptionMetadata.a);
        }
    }
    SummaryRowDescriptionMetadata.$t = /*@__PURE__*/ markType(SummaryRowDescriptionMetadata, 'SummaryRowDescriptionMetadata');
    SummaryRowDescriptionMetadata.a = null;
    return SummaryRowDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/SummaryRowDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
/**
 * @hidden
 */
export let SummaryRowDescriptionMetadata = /*@__PURE__*/ (() => {
    class SummaryRowDescriptionMetadata extends Base {
        static b(a) {
            if (SummaryRowDescriptionMetadata.a == null) {
                SummaryRowDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                SummaryRowDescriptionMetadata.c(SummaryRowDescriptionMetadata.a);
            }
            if (a.k(SummaryRowDescriptionMetadata.a)) {
                return;
            }
            a.aa(SummaryRowDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
            a.item("SelectedBackground", "Brush");
            a.item("ActualSelectedBackground", "Brush");
            a.item("SummaryLabelTextColor", "Brush");
            a.item("ActualSummaryLabelTextColor", "Brush");
            a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:summaryNameTextStyle/FontFamilyTransform)String");
            a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:summaryNameTextStyle/FontSizeTransform)Number:double");
            a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:summaryNameTextStyle/FontStyleTransform)String");
            a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:summaryNameTextStyle/FontWeightTransform)String");
            a.item("PaddingLeft", "Number:int");
            a.item("PaddingTop", "Number:int");
            a.item("PaddingRight", "Number:int");
            a.item("PaddingBottom", "Number:int");
        }
        static d(a) {
            SummaryRowDescriptionMetadata.b(a);
            a.ab("SummaryRow", SummaryRowDescriptionMetadata.a);
        }
    }
    SummaryRowDescriptionMetadata.$t = /*@__PURE__*/ markType(SummaryRowDescriptionMetadata, 'SummaryRowDescriptionMetadata');
    SummaryRowDescriptionMetadata.a = null;
    return SummaryRowDescriptionMetadata;
})();
